==> perl-DateTime-Locale-1.22-1-src.tar.xz: DateTime-Locale-1.22/share/haw.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "haw",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
    "P5",
    "P6",
    "LP",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Po\N{U+02bb}akahi",
    "Po\N{U+02bb}alua",
    "Po\N{U+02bb}akolu",
    "Po\N{U+02bb}ah\N{U+0101}",
    "Po\N{U+02bb}alima",
    "Po\N{U+02bb}aono",
    "L\N{U+0101}pule",
  ],
  day_stand_alone_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
    "P5",
    "P6",
    "LP",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Po\N{U+02bb}akahi",
    "Po\N{U+02bb}alua",
    "Po\N{U+02bb}akolu",
    "Po\N{U+02bb}ah\N{U+0101}",
    "Po\N{U+02bb}alima",
    "Po\N{U+02bb}aono",
    "L\N{U+0101}pule",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Hawaiian",
  month_format_abbreviated => [
    "Ian.",
    "Pep.",
    "Mal.",
    "\N{U+02bb}Ap.",
    "Mei",
    "Iun.",
    "Iul.",
    "\N{U+02bb}Au.",
    "Kep.",
    "\N{U+02bb}Ok.",
    "Now.",
    "Kek.",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Ianuali",
    "Pepeluali",
    "Malaki",
    "\N{U+02bb}Apelila",
    "Mei",
    "Iune",
    "Iulai",
    "\N{U+02bb}Aukake",
    "Kepakemapa",
    "\N{U+02bb}Okakopa",
    "Nowemapa",
    "Kekemapa",
  ],
  month_stand_alone_abbreviated => [
    "Ian.",
    "Pep.",
    "Mal.",
    "\N{U+02bb}Ap.",
    "Mei",
    "Iun.",
    "Iul.",
    "\N{U+02bb}Au.",
    "Kep.",
    "\N{U+02bb}Ok.",
    "Now.",
    "Kek.",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Ianuali",
    "Pepeluali",
    "Malaki",
    "\N{U+02bb}Apelila",
    "Mei",
    "Iune",
    "Iulai",
    "\N{U+02bb}Aukake",
    "Kepakemapa",
    "\N{U+02bb}Okakopa",
    "Nowemapa",
    "Kekemapa",
  ],
  name => "Hawaiian",
  native_language => "\N{U+02bb}\N{U+014c}lelo Hawai\N{U+02bb}i",
  native_name => "\N{U+02bb}\N{U+014c}lelo Hawai\N{U+02bb}i",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 33,
}

==> perl-DateTime-Locale-1.24-1-src.tar.xz: DateTime-Locale-1.24/share/haw.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "haw",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
    "P5",
    "P6",
    "LP",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Po\N{U+02bb}akahi",
    "Po\N{U+02bb}alua",
    "Po\N{U+02bb}akolu",
    "Po\N{U+02bb}ah\N{U+0101}",
    "Po\N{U+02bb}alima",
    "Po\N{U+02bb}aono",
    "L\N{U+0101}pule",
  ],
  day_stand_alone_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
    "P5",
    "P6",
    "LP",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Po\N{U+02bb}akahi",
    "Po\N{U+02bb}alua",
    "Po\N{U+02bb}akolu",
    "Po\N{U+02bb}ah\N{U+0101}",
    "Po\N{U+02bb}alima",
    "Po\N{U+02bb}aono",
    "L\N{U+0101}pule",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Hawaiian",
  month_format_abbreviated => [
    "Ian.",
    "Pep.",
    "Mal.",
    "\N{U+02bb}Ap.",
    "Mei",
    "Iun.",
    "Iul.",
    "\N{U+02bb}Au.",
    "Kep.",
    "\N{U+02bb}Ok.",
    "Now.",
    "Kek.",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Ianuali",
    "Pepeluali",
    "Malaki",
    "\N{U+02bb}Apelila",
    "Mei",
    "Iune",
    "Iulai",
    "\N{U+02bb}Aukake",
    "Kepakemapa",
    "\N{U+02bb}Okakopa",
    "Nowemapa",
    "Kekemapa",
  ],
  month_stand_alone_abbreviated => [
    "Ian.",
    "Pep.",
    "Mal.",
    "\N{U+02bb}Ap.",
    "Mei",
    "Iun.",
    "Iul.",
    "\N{U+02bb}Au.",
    "Kep.",
    "\N{U+02bb}Ok.",
    "Now.",
    "Kek.",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Ianuali",
    "Pepeluali",
    "Malaki",
    "\N{U+02bb}Apelila",
    "Mei",
    "Iune",
    "Iulai",
    "\N{U+02bb}Aukake",
    "Kepakemapa",
    "\N{U+02bb}Okakopa",
    "Nowemapa",
    "Kekemapa",
  ],
  name => "Hawaiian",
  native_language => "\N{U+02bb}\N{U+014c}lelo Hawai\N{U+02bb}i",
  native_name => "\N{U+02bb}\N{U+014c}lelo Hawai\N{U+02bb}i",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 35,
}
